==> gbsite-1.1.1.tar.gz: gbsite/templates/master/master_taskshowpage.php <==
<table cellspacing="0" cellpadding="4" border="0" width="100%">
<tr>
<td colspan="3"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2">The following task was created by <b><?= getMemberName($task["created_by"]) ?></b> on <?= date("F d, Y",strtotime($task["date_created"])) ?>:</font><br><br></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b>Task:</b> <?= $task["task_name"] ?></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><b>Status:</b> <?= $status_list[$task["status_id"]]["name"] ?></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Owner:</b> <?= getMemberName($task["assigned_to"]) ?></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><b>Priority:</b> <?= $task["priority"] ?></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Start Date:</b> <?= date("m/d/Y",strtotime($task["start_date"])) ?></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><b>End Date:</b> <?= date("m/d/Y",strtotime($task["end_date"])) ?></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Estimated Completion Time:</b> <?= $task["hours"] ?> hours</font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><b>Progress:</b> <?= $task["percent_done"] ?>%</font></td>
</tr>
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2"><b>Comments/Description:</b></font></td>
</tr>
<tr>
<td colspan="3">
<blockquote>
<font face="<?= $font_1 ?>" size="2">
<?= nl2br($task["comments"]) ?>
</font>
</blockquote>
</td>
</tr>
<tr>
<td colspan=3>
<font face="<?= $font_1 ?>" size="2"><b>Attached Bugs:</b></font><br>
<? if(empty($bug_list)) { ?>
<blockquote>There are no bugs attached to this task.</blockquote>
<? } else { ?>
<blockquote>
<? while(list(,$bug) = @each($bug_list)) { ?>
<a href="/project/<?= $project_name ?>/bugs/bugupdate.php?<?= $bug["bug_id"] ?>"><?= $bug["title"] ?></a><br>
<? } ?>
</blockquote>
<? } ?>
</td>
</tr>
<? if($access_level == 4 || $task["assigned_to"] == $member_id) { ?>
<tr>
<td colspan="3" align="right">
<br>
<font face="<?= $font_1 ?>" size="2"><b><? echo "<a href=\"/project/$project_name/task/taskedit.php?${task["task_id"]}\">Edit/Update Task</a><br>\n"; ?></b></font>
<? } ?>
</td>
</tr>
</table>

==> gbsite-2.0.0.tar.gz: gbsite/templates/master/master_taskshowpage.php <==
<table cellspacing="0" cellpadding="4" border="0" width="100%">
<tr>
<td colspan="3"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2">The following task was created by <b><?= getMemberName($task["created_by"]) ?></b> on <?= date("F d, Y",strtotime($task["date_created"])) ?>:</font><br><br></td>
</tr>
<tr>
<td><font face="<?= $font_1 ?>" size="2"><b>Task:</b> <?= $task["task_name"] ?> (ID: <?= $task["task_id"] ?>)</font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><b>Status:</b> <?= $status_list[$task["status_id"]]["name"] ?></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Owner:</b> <?= getMemberName($task["assigned_to"]) ?></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><b>Priority:</b> <?= $task["priority"] ?></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Start Date:</b> <?= date("m/d/Y",strtotime($task["start_date"])) ?></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><b>End Date:</b> <?= date("m/d/Y",strtotime($task["end_date"])) ?></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Estimated Completion Time:</b> <?= $task["hours"] ?> hours</font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><font face="<?= $font_1 ?>" size="2"><b>Progress:</b> <?= $task["percent_done"] ?>%</font></td>
</tr>
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2"><b>Comments/Description:</b></font></td>
</tr>
<tr>
<td colspan="3">
<blockquote>
<font face="<?= $font_1 ?>" size="2">
<?= nl2br($task["comments"]) ?>
</font>
</blockquote>
</td>
</tr>
<tr>
<td colspan=3>
<font face="<?= $font_1 ?>" size="2"><b>Attached Bugs:</b></font><br>
<? if(empty($bug_list)) { ?>
<blockquote>There are no bugs attached to this task.</blockquote>
<? } else { ?>
<blockquote>
<? while(list(,$bug) = @each($bug_list)) { ?>
<a href="/project/<?= $project_name ?>/bugs/bugupdate.php?<?= $bug["bug_id"] ?>"><?= $bug["title"] ?></a><br>
<? } ?>
</blockquote>
<? } ?>
</td>
</tr>
<? if($access_level >= 3 || $task["assigned_to"] == $member_id) { ?>
<tr>
<td colspan="3" align="right">
<br>
<font face="<?= $font_1 ?>" size="2"><b><? echo "<a href=\"/project/$project_name/task/taskedit.php?${task["task_id"]}\">Edit/Update Task</a><br>\n"; ?></b></font>
<? } ?>
</td>
</tr>
</table>
